==> apimgmt-app-1.1.0-20251024.055834-1-sources.jar: com/digiwin/athena/apimgmt/model/StandardApiDataName.java <==
package com.digiwin.athena.apimgmt.model;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.google.gson.annotations.Expose;
import com.google.gson.annotations.SerializedName;
import lombok.Data;
import lombok.EqualsAndHashCode;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

/**
 * The persistent class for the standard_api_data_name database table.
 *
 */
@Data
@TableName("standard_api_data_name")
@EqualsAndHashCode(exclude = {"standardApiVersion", "parent", "childrens", "productApiDataNames"})
public class StandardApiDataName implements Serializable {
	private static final long serialVersionUID = 1L;

    @TableId(type = IdType.AUTO)
	private Long id;

    @TableField("api_ver_id")
	private Integer apiVerId;

    @TableField("api_ver")
	private String apiVer;

    @TableField("column_type")
	@Expose()
	private String columnType;

    @TableField("data_type")
	private String dataType;

    @TableField("msg_type")
	@Expose()
	private Integer msgType;

	@Deprecated
	@Expose()
	private Boolean nullable;

    @TableField("is_required")
	@Expose()
	private Boolean isRequired;

    @TableField("remark_en_us")
	@Expose()
	private String remarkEnUs;

    @TableField("remark_zh_cn")
	@Expose()
	private String remarkZhCn;

    @TableField("remark_zh_tw")
	@Expose()
	private String remarkZhTw;

    @TableField("description_en_us")
	@Expose()
	private String descriptionEnUs;

    @TableField("description_zh_cn")
	@Expose()
	private String descriptionZhCn;

    @TableField("description_zh_tw")
	@Expose()
	private String descriptionZhTw;

    @TableField("list_enum_zh_tw")
	@Expose()
	private String listEnumZhTw;

    @TableField("list_enum_zh_cn")
	@Expose()
	private String listEnumZhCn;

    @TableField("list_enum_en")
	@Expose()
	private String listEnumEn;

    @TableField("update_history")
	private String updateHistory;

	private String value;

    @TableField("is_datakey")
	@Expose()
	private Boolean isDatakey;

    @TableField("is_array")
	@Expose()
	private Boolean isArray;

    @TableField("can_sort")
	@Expose()
	private Boolean canSort;

	// by songwq 新增过滤字段
    @TableField("can_filter")
	@Expose()
	private Boolean canFilter;

    @TableField("is_businesskey")
	@Expose()
	private Boolean isBusinesskey;

    @TableField(exist = false)
	private StandardApiVersion standardApiVersion;

    @TableField("parent")
    private Long parentId;
    @TableField(exist = false)
	// bi-directional many-to-one association to StandardApiDataName
	private StandardApiDataName parent;

	// bi-directional many-to-one association to StandardApiDataName
	@Expose()
    @TableField(exist = false)
	private List<StandardApiDataName> childrens = new ArrayList<>();

	//bi-directional many-to-one association to StandardApiDataName
    @TableField(exist = false)
	private List<ProductApiDataName> productApiDataNames  = new ArrayList<>();

    @TableField("data_name")
	@Expose()
	@SerializedName("dataName")
	private String standardDataName;

	public StandardApiDataName() {
	}

    public void setIsRequired(Boolean isRequired) {
		this.nullable = !isRequired;
		this.isRequired = isRequired;
	}

    public StandardApiDataName addChildren(StandardApiDataName standardApiDataName) {
		getChildrens().add(standardApiDataName);
		standardApiDataName.setParent(this);

		return standardApiDataName;
	}

    public ProductApiDataName addProductApiDataName(ProductApiDataName productApiDataName) {
		getProductApiDataNames().add(productApiDataName);
		productApiDataName.setApiDataName(this);

		return productApiDataName;
	}

}

==> apimgmt-app-1.1.0-20251027.043440-5-sources.jar: com/digiwin/athena/apimgmt/model/StandardApiDataName.java <==
package com.digiwin.athena.apimgmt.model;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.google.gson.annotations.Expose;
import com.google.gson.annotations.SerializedName;
import lombok.Data;
import lombok.EqualsAndHashCode;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

/**
 * The persistent class for the standard_api_data_name database table.
 *
 */
@Data
@TableName(value = "standard_api_data_name", resultMap = "BaseResultMap")
@EqualsAndHashCode(exclude = {"standardApiVersion", "parent", "childrens", "productApiDataNames"})
public class StandardApiDataName implements Serializable {
	private static final long serialVersionUID = 1L;

    @TableId(type = IdType.AUTO)
    private Long id;

    @TableField("api_ver_id")
    private Integer apiVerId;

    @TableField("api_ver")
	private String apiVer;

    @TableField("column_type")
	@Expose()
	private String columnType;

    @TableField("data_type")
	private String dataType;

    @TableField("msg_type")
	@Expose()
	private Integer msgType;

	@Deprecated
	@Expose()
	private Boolean nullable;

    @TableField("is_required")
	@Expose()
	private Boolean isRequired;

    @TableField("remark_en_us")
	@Expose()
	private String remarkEnUs;

    @TableField("remark_zh_cn")
	@Expose()
	private String remarkZhCn;

    @TableField("remark_zh_tw")
	@Expose()
	private String remarkZhTw;

    @TableField("description_en_us")
	@Expose()
	private String descriptionEnUs;

    @TableField("description_zh_cn")
	@Expose()
	private String descriptionZhCn;

    @TableField("description_zh_tw")
	@Expose()
	private String descriptionZhTw;

    @TableField("list_enum_zh_tw")
	@Expose()
	private String listEnumZhTw;

    @TableField("list_enum_zh_cn")
	@Expose()
	private String listEnumZhCn;

    @TableField("list_enum_en")
	@Expose()
	private String listEnumEn;

    @TableField("update_history")
	private String updateHistory;

	private String value;

    @TableField("is_datakey")
	@Expose()
	private Boolean isDatakey;

    @TableField("is_array")
	@Expose()
	private Boolean isArray;

    @TableField("can_sort")
	@Expose()
	private Boolean canSort;

	// by songwq 新增过滤字段
    @TableField("can_filter")
	@Expose()
	private Boolean canFilter;

    @TableField("is_businesskey")
	@Expose()
	private Boolean isBusinesskey;

    @TableField(exist = false)
	private StandardApiVersion standardApiVersion;

    @TableField("parent")
    private Long parentId;
    @TableField(exist = false)
	// bi-directional many-to-one association to StandardApiDataName
	private StandardApiDataName parent;

	// bi-directional many-to-one association to StandardApiDataName
	@Expose()
    @TableField(exist = false)
	private List<StandardApiDataName> childrens = new ArrayList<>();

	//bi-directional many-to-one association to StandardApiDataName
    @TableField(exist = false)
	private List<ProductApiDataName> productApiDataNames  = new ArrayList<>();

    @TableField("data_name")
	@Expose()
	@SerializedName("dataName")
	private String standardDataName;

	public StandardApiDataName() {
	}

    public void setIsRequired(Boolean isRequired) {
		this.nullable = !isRequired;
		this.isRequired = isRequired;
	}

    public StandardApiDataName addChildren(StandardApiDataName standardApiDataName) {
		getChildrens().add(standardApiDataName);
		standardApiDataName.setParent(this);

		return standardApiDataName;
	}

    public ProductApiDataName addProductApiDataName(ProductApiDataName productApiDataName) {
		getProductApiDataNames().add(productApiDataName);
		productApiDataName.setApiDataName(this);

		return productApiDataName;
	}

}
